@@ -233,6 +233,7 @@ class DataPlate:
                     bucket_filter=None,
                     force_scheme_change=False,
                     recursive_lookup_no_partitions=False,
+                    enable_replay=False,
                     **kwargs):
         """
         Executes remote SQL query, and returns Pandas dataframe.
@@ -264,6 +265,9 @@ class DataPlate:
             Note: this requires an EMR cluster > 6.3.0 with spark 3
             If True you'll be able to read data from subfolders, even though no partitions were defined
             default is False - meaning you have to define sub-folders as partitions (e.g "customer=customer1")
+        enable_replay (BETA - NOT Working yet): boolean
+            If True, enable you to replay the specific data that was queried in the specific query (restore data for retrospective needs)
+            Data for replay will be expired after 14 days (default configuration)
         **kwargs : params
             Arbitrary parameters to pass to `pandas.read_json()` method
 
@@ -1661,4 +1665,176 @@ class DataPlate:
 
         except Exception as e:
             logging.exception('stop_run_notebook , ' + str(e))
-            raise Error(e)
\ No newline at end of file
+            raise Error(e)
+
+
+    def recreate_inference_endpoint(self, endpoint_name, container_full_name, instance_type="ml.m5.large", initial_instance_count=1,
+                                    initial_variant_weight=1, mode="SingleModel", model_url=None, securityGroupIds=[], subnets=[], role=None):
+        """ Create/Update an inference EndPoint in SageMaker - including recreate model, configuration resigtry and endpoint
+        Args:
+            endpoint_name (str): The name for the endpoint,model and endpoint config
+            container_full_name (str): full container name e.g. YOUR_AWS_ACCOUNTID.dkr.ecr.us-east-1.amazonaws.com/my_container:latest
+            instance_type (str): The SageMaker instance to use (default: ml.m5.large).
+            initial_instance_count : Initial amount of instances to start from (with or without auto scaling)
+            initial_variant_weight : Determines initial traffic distribution among all of the models e.g 0.5 is 50% (default = 1.0)
+            mode : SingleModel | MultiModel (default is SingleModel)
+            model_url : In case of MultiModel ,the maximum s3 path that all models are located in
+            securityGroupIds : a list of securityGroup Ids of aws for the processing job to communicate with, in case communication with other resources, e.g. internal dataplate service, is needed
+            subnets : a list of subnets of aws for the processing job to communicate with
+            role : a role ARN to run the notebook, the default is the Dataplate service role (cross rols in case of Sass)
+        Returns:
+            The arn of the inference EndPoint created
+        """
+        try:
+            if not endpoint_name or len(endpoint_name) == 0:
+                raise FileNotFoundError(
+                    f'model_name is not legal/valid : {endpoint_name if endpoint_name else "None"}')
+
+
+            if not container_full_name or len(container_full_name) < 47 :
+                raise Error(f'please check your container_full_name : {container_full_name if container_full_name else "None"}')
+
+            params = {}
+            if instance_type:
+                params['instance_type'] = instance_type
+            if initial_instance_count:
+                params['initial_instance_count'] = initial_instance_count
+            if initial_variant_weight:
+                params['initial_variant_weight'] = initial_variant_weight
+            params['SecurityGroupIds'] = json.dumps(
+                securityGroupIds)  # ','.join(['"%s"' % w for w in securityGroupIds])
+            params['Subnets'] = json.dumps(subnets)  # ','.join(['"%s"' % w for w in subnets])
+            params['endpoint_name'] = endpoint_name
+            params['container_full_name'] = container_full_name
+            params['mode'] = mode
+            if model_url:
+                params['model_url'] = model_url
+            if role:
+                params['role'] = role
+
+            headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
+
+            try:
+                logging.info('Deleting previous endpoint...')
+                r = self.session.post( \
+                    '{}/api/aws/deleteEndpoint'.format(self.base_url), params=params,
+                    data=json.dumps({}),
+                    headers=headers, stream=True, allow_redirects=False)
+
+                if r.status_code != 200:
+                    if r.status_code == 302:
+                        raise Error(
+                            'Bad Access Key! Get your access key at: {}'.format(
+                                self.base_url))
+                    if r.status_code == 206:
+                        logging.info('re-creating inference endpoint, processing...')
+                        time.sleep(5)
+                    raise Error(
+                        'Bad HTTP exit status returned from the API: {}. Error was: {}'.
+                            format(r.status_code, r.text))
+
+                logging.info('Parsing response')
+                # logging.info(str(r.text))
+                if r.text:
+                    logging.info('delete inference endpoint finished successfully')
+                    logging.info(r.text)  # json.dumps(rJson)
+                else:
+                    logging.exception('Could not find proper output, please check your parameters')
+                # return r.text
+
+            except (requests.exceptions.ConnectionError,
+                    requests.exceptions.ReadTimeout) as e:
+                logging.exception('Got ConnectionError/ReadTimeout exception.')
+                raise Error(e)
+            except Exception as e:
+                logging.exception('Could not find relevant endpoint - continue to create')
+
+            try:
+                logging.info('Creating endpoint...')
+                r = self.session.post( \
+                    '{}/api/aws/recreateEndpoint'.format(self.base_url), params=params,
+                    data=json.dumps({}),
+                    headers=headers, stream=True, allow_redirects=False)
+
+                if r.status_code != 200:
+                    if r.status_code == 302:
+                        raise Error(
+                            'Bad Access Key! Get your access key at: {}'.format(
+                                self.base_url))
+                    if r.status_code == 206:
+                        logging.info('re-creating inference endpoint, processing...')
+                        time.sleep(5)
+                    raise Error(
+                        'Bad HTTP exit status returned from the API: {}. Error was: {}'.
+                            format(r.status_code, r.text))
+
+                logging.info('Parsing response')
+                # logging.info(str(r.text))
+                if r.text:
+                    logging.info('re-creating inference endpoint finished successfully - it may take few minute for it to be available.')
+                    return r.text  # json.dumps(rJson)
+                else:
+                    logging.exception('Could not find proper output, please check your parameters')
+                # return r.text
+
+            except (requests.exceptions.ConnectionError,
+                    requests.exceptions.ReadTimeout) as e:
+                logging.exception('Got ConnectionError/ReadTimeout exception.')
+                raise Error(e)
+
+        except Exception as e:
+            logging.exception('recreate_inference_endpoint , ' + str(e))
+            raise Error(e)
+
+
+
+    def delete_inference_endpoint(self, endpoint_name):
+        """ Delete an inference EndPoint in SageMaker - includes deleting also configuration resigtry , model and endpoint
+        Args:
+            endpoint_name (str): The name for the endpoint,model and endpoint config (should be the same name for all)
+        """
+        try:
+            if not endpoint_name or len(endpoint_name) == 0:
+                raise FileNotFoundError(
+                    f'model_name is not legal/valid : {endpoint_name if endpoint_name else "None"}')
+
+
+            params = {}
+            params['endpoint_name'] = endpoint_name
+
+            headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
+
+            logging.info('Deleting endpoint...')
+            r = self.session.post( \
+                '{}/api/aws/deleteEndpoint'.format(self.base_url), params=params,
+                data=json.dumps({}),
+                headers=headers, stream=True, allow_redirects=False)
+
+            if r.status_code != 200:
+                if r.status_code == 302:
+                    raise Error(
+                        'Bad Access Key! Get your access key at: {}'.format(
+                            self.base_url))
+                if r.status_code == 206:
+                    logging.info('re-creating inference endpoint, processing...')
+                    time.sleep(5)
+                raise Error(
+                    'Bad HTTP exit status returned from the API: {}. Error was: {}'.
+                        format(r.status_code, r.text))
+
+            logging.info('Parsing response')
+            # logging.info(str(r.text))
+            if r.text:
+                logging.info('delete inference endpoint finished successfully')
+                logging.info(r.text)  # json.dumps(rJson)
+            else:
+                logging.exception('Could not find proper output, please check your parameters')
+            # return r.text
+
+        except (requests.exceptions.ConnectionError,
+                requests.exceptions.ReadTimeout) as e:
+            logging.exception('Got ConnectionError/ReadTimeout exception.')
+            raise Error(e)
+        except Exception as e:
+            logging.exception('Could not find relevant endpoint')
+
